import { Files } from '../files';
import { createLog } from '../log'
import type { Logger } from 'winston';
import type { SequenceObject, ImageObject } from '../files';
import type { FD } from '../fd';
import type { Camera } from '../camera';
import type { Display } from '../display';
import type { FFPROBE } from '../ffprobe';

export class Sequence {
	private log : Logger;
	private current : SequenceObject = null;
	private images : ImageObject[] = [];
	private camera : Camera;
	private display : Display;
	private ffprobe : FFPROBE;
	private fd : FD;
	private running : boolean;
	private progress : number;
	private frames : number;

	constructor (camera : Camera, fd : FD, display: Display, ffprobe : FFPROBE) {
		this.log = createLog('seq');
		this.camera = camera;
		this.fd = fd;
		this.display = display;
		this.ffprobe = ffprobe;
	}

	public start () {
		this.running = true;
	}

	public stop () {
		this.running = false;
	}

	public isRunning () {
		return this.running;
	}

	public load (seq : SequenceObject) {
		this.current = seq;
		this.enumerate();
	}

	private async enumerate () {
		if (this.current === null)  {
			this.log.error('Cannot enumerate sequence because it is not set');
			return;
		}

		try {
			this.images = await Files.enumerateSequence(this.current.path);
		} catch (err) {
			this.log.error(`Error enumerating images in sequence: ${this.current.name}`, err);
			return;
		}

		this.log.info(`Sequence ${this.current.name} contains ${this.images.length} image${this.images.length === 1 ? '' : 's'}`);

		if (this.images.length > 0) {
			console.dir(await this.ffprobe.info(this.images[0].path));
		}
	}

	public unload () {
		this.current = null;
		this.images = [];
	}

	public getState () : SequenceState {
		return {
			hash : this.current.hash,
			name : this.current.name,
			progress : this.progress
		}
	}
}